function v=compute_ekman_surge_cetn(vmax,rmax,r35,vt,phi,phi_in,w,a,n,lat)
% Computes ekman_surge_cetn
% Script automatically generated by fit_ekman_surge_cetn.m
% Inputs : 
% vmax           = Vmax (km/h)
% rmax           = Rmax (km)
% r35            = R35 (km)
% vt             = forward speed (km/h)
% phi            = track angle (deg)
% phi_in         = inflow angle (deg)
% w              = shelf width (km)
% a              = Dean slope a (-)
% n              = Mannings n
% lat            = latitude (deg)

% R2    = 0.33606
% RMSE  = 2.9364
% MEAN  = 8.18
% RANGE = 2.1667 - 17.6667

beta( 1 )= 0.0000e+00 ;
beta( 2 )= 8.2515e-02 ;
beta( 3 )= 1.0000e+00 ;
beta( 4 )= 1.5332e-01 ;
beta( 5 )= 5.3349e+00 ;
beta( 6 )= 7.7984e+02 ;
beta( 7 )= 2.6052e-01 ;
beta( 8 )= 1.0000e+00 ;
beta( 9 )= -1.5251e+02 ;
beta( 10 )= 1.5007e+02 ;
beta( 11 )= 6.6505e+01 ;
beta( 12 )= -1.6604e+01 ;

v=(beta(1) + beta(2)*r35.^beta(3) + beta(4)*lat + beta(5).*vt + beta(6)*a.^beta(8) + beta(7)*w + beta(9).*tanh(vmax/beta(10)) + beta(11)*cos((phi-beta(12))*pi/180) ) ./ ((cos(phi*pi/180).*vt));
